#
# spec file for package python-python-rapidjson
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# check git submodule and update devel:libraries:c_c++/rapidjson
%define rjversion 1.1.0+git20211015.4d6cb081
%{?sle15_python_module_pythons}
Name:           python-python-rapidjson
Version:        1.13
Release:        1.1
Summary:        Python wrapper around rapidjson
License:        MIT
URL:            https://github.com/python-rapidjson/python-rapidjson
Source:         https://github.com/python-rapidjson/python-rapidjson/archive/v%{version}.tar.gz#/python-rapidjson-%{version}.tar.gz
Patch0:         rapidjson-system.patch
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module devel >= 3.6}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
BuildRequires:  rapidjson-devel = %{rjversion}
%python_subpackages

%description
RapidJSON is a C++ JSON parser and serialization library. This
module wraps it into a Python 3 extension, exposing its
serialization/deserialization (to/from either bytes, str or file-like
instances) and JSON Schema validation capabilities.

%prep
%setup -q -n python-rapidjson-%{version}
%patch0 -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export LANG=en_US.UTF-8
%pytest_arch tests -s

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE
%{python_sitearch}/rapidjson.*.so
%{python_sitearch}/python_rapidjson-%{version}*-info

%changelog
* Thu Nov 23 2023 ecsos <ecsos@opensuse.org>
- Update to 1.13
  * Fix handling of write_mode in dump functions (problem emerged discussing issue #191)
- Update to 1.12
  * Generate wheels on PyPI using final Python 3.12 release, thanks to cibuildwheel 2.16.2
- Update to 1.11
  * Use current master version of rapidjson
  * Use cibuildwheel 2.15.0
- Update to 1.10
  * Use current master version of rapidjson
  * Produce ppc64le wheels, thanks to mgiessing (PR #170)
  * Use cibuildwheel 2.12.1
- Add %%{?sle15_python_module_pythons}
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.9
  * Produce Python 3.11 wheels, thanks to cibuildwheel 2.11.1.
* Thu Oct  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.8 (2022-07-07)
  Fix problem on macOS explicitly requiring C++11, thanks to agate-pris (issue #166)
- Update to version 1.7 (2022-07-06)
  Use current master version of rapidjson
  Update the test suite to work on Pyston, thanks to Kevin Modzelewski (PR #161)
- Update to version 1.6 (2022-02-19)
  Fix memory leak when using end_array (issue #160)
* Thu Jan 13 2022 Ben Greiner <code@bnavigator.de>
- Update to v1.5
  * Fix serialization bug when using DM_UNIX_TIME in a non-C locale
    context
- Release 1.1 - 1.4
  * wheel related
- Release 1.1
  * Reduce decoder memory consumption by uniquifiying keys in the
    loaded dictionaries
  * Implement an alternative way of transmogrify JSON objects,
    similar to json's object_pairs_hook load option (issue #154)
- Release 1.0
  * Require Python 3.6 or greater
  * New serialization options, iterable_mode and mapping_mode, to
    give some control on how generic iterables and mappings get
    encoded (fix issue #149 and issue #150)
  * Internal refactorings, folding "skipkeys" and "sort_keys"
    arguments into the mapping_mode options, respectively as
    MM_SKIP_NON_STRING_KEYS and MM_SORT_KEYS: "old" arguments kept
    for backward compatibility
  * Bump major version to 1, tag as "production/stable" and switch
    to a simpler X.Y versioning schema
- Release 0.9.4
  * Fix memory leak loading an invalid JSON (issue #148)
- Release 0.9.3
  * Fix access to Encoder instance attributes (issue #147)
- Release 0.9.2
  * Use current master version of rapidjson
  * Enable GH Actions-based test workflow, thanks to Martin Thoma
    (PR #143)
  * Produce Python 3.9 wheels, disable testing under Python < 3.6
  * Make the character used for indentation in pretty mode a
    parameter (issue #135)
  * Handle wider precision range in timestamps fractional seconds
    (PR 133), thanks to Karl Seguin
  * Add comparison benchmarks against orjson and hyperjson (issue
    [#130] and PR #131, thanks to Sebastian Pipping)
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.1:
  * Compatibility fix for Python 3.8 (issue #125)
  * Fix memory leak in case of failed validation (issue 126)
* Mon Oct  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call to run on sitearch not sitelib
* Wed Aug 28 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.8.0
  * New serialization option bytes_mode to control how bytes instances gets encoded
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.2:
  * Hopefully fix the memory leak when loading from a stream (issue #117)
* Mon Jun 10 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description.
* Wed Jun  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.1:
  * Raise a more specific exception on loading errors, JSONDecodeError, instead of generic ValueError (issue #118)
  * Fix optimization path when using OrderedDicts (issue #119)
  * Fix serialization of IntEnums (issue #121)
  * Raise correct exception in code samples (PR #109), thanks to Thomas Dähling
  * Fix compilation with system-wide install of rapidjson (issue #110)
  * Use current master version of rapidjson, that includes a fix for its issue #1368 and issue #1336, and cures several compilation warnings as well (issue #112 and issue #107)
  * Fix memory leak when using object_hook (issue #115)
- Add patch to enforce use of system rapidjson:
  * rapidjson-system.patch
* Thu Nov 22 2018 Karol Babioch <kbabioch@suse.de>
- Initial packaging of version 0.6.3
